| angles.csa | R Documentation |
Computes the cosines similarities and angles between the components of a CSA and those of a MCA.
angles.csa(rescsa, resmca, naxes = 3)
rescsa |
object of class |
resmca |
object of class |
naxes |
integer. Number of axes to retain. Default is 3. |
A list of matrices:
cosines |
Cosine similarities between CSA and MCA dimensions |
angles.with.dims |
Angles between CSA and MCA dimensions |
angles.with.planes |
Angles between CSA dimensions and MCA planes |
best.planes |
Angles between each CSA dimension and its closest MCA plane |
Lucas Page Pereira, Nicolas Robette
Le Roux B. and Rouanet H., Multiple Correspondence Analysis, SAGE, Series: Quantitative Applications in the Social Sciences, Volume 163, CA:Thousand Oaks (2010).
Le Roux B. and Rouanet H., Geometric Data Analysis: From Correspondence Analysis to Stuctured Data Analysis, Kluwer Academic Publishers, Dordrecht (June 2004).
MCA, speMCA, csMCA
## Performs a specific MCA and a CSA on the Music example data set
## and computes cosine similarities and angles
data(Music)
junk <- c("FrenchPop.NA", "Rap.NA", "Rock.NA", "Jazz.NA", "Classical.NA")
resmca <- speMCA(Music[,1:5], excl = junk)
female <- Music$Gender=="Women"
rescsa <- csMCA(Music[,1:5], subcloud = female, excl = junk)
angles.csa(rescsa, resmca)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.