- p
ggplot2 object with the cloud of variables
- resmca
object created with MCA, speMCA, csMCA, wcMCA, bcMCA, stMCA or multiMCA function
- vars
A data frame of categorical supplementary variables. All these variables should be factors.
- excl
character vector of supplementary categories to exclude from the plot, specified in the form "namevariable.namecategory" (for instance "Gender.Men"). If NULL (default), all the supplementary categories are plotted.
- points
character string. If 'all' all categories are plotted (default); if 'besth' only those with a minimum squared cosine on horizontal axis are plotted; if 'bestv' only those with a minimum squared cosine on vertical axis are plotted; if 'besthv' only those with a minimum squared cosine on horizontal or vertical axis are plotted; if 'best' only those with a minimum squared cosine on the plane are plotted.
- min.cos2
numerical value. The minimal squared cosine if 'points' argument is different from 'all'. Default
- axes
numeric vector of length 2, specifying the components (axes) to plot. Default is c(1,2).
- col
character string. Color name for the labels (and the shapes if shapes=TRUE) of the categories. If NULL, the default palette of ggplot2 is used, with one color per variable.
- shapes
Logical. If TRUE, symbols are used in addition to the labels of categories. Default is FALSE.
- prop
If NULL, the size of the labels (if shapes=FALSE), or of the labels and the shapes (if shapes=TRUE) is constant. If 'n', the size is proportional the the weights of categories; if 'vtest1', the size is proportional to the test values of the categories on the first dimension of the plot; if 'vtest2', the size is proportional to the test values of the categories on the second dimension of the plot; if 'cos1', the size is proportional to the cosines of the categories on the first dimension of the plot; if 'cos2', the size is proportional to the cosines of the categories on the second dimension of the plot; if 'cos12', the size is proportional to the total cosines of the categories on the two dimensions of the plot.
- textsize
Size of the labels of categories if shapes is TRUE, or if shapes is FALSE and prop is NULL. Default is 3.
- shapesize
Size of the shapes if prop=NULL, maximum size of the shapes in other cases. Default is 6.
- vlab
Logical. If TRUE (default), the variable name is added as a prefix for the labels of the categories.
- vname
deprecated, use vlab instead
- force
Force of repulsion between overlapping text labels. Defaults to 1. If 0, labels are not repelled at all.
- max.overlaps
Exclude text labels that overlap too many things. Defaults to Inf, which means no labels are excluded.