- resmca
object created with MCA, speMCA, csMCA, wcMCA, bcMCA, stMCA or multiMCA function
- type
If 'i', points are plotted. If 'inames', labels of individuals are plotted.
- points
character string. If 'all' all points are plotted (default). If 'besth' only those who contribute most to horizontal axis are plotted. If 'bestv' only those who contribute most to vertical axis are plotted. If 'besthv' only those who contribute most to horizontal or vertical axis are plotted. If 'best' only those who contribute most to the plane are plotted.
- axes
numeric vector of length 2, specifying the components (axes) to plot. Default is c(1,2).
- col
If a factor, points or labels are colored according to their category regarding this factor. If a string with color name, every points or labels have the same color. Default is "dodgerblue4".
- point.size
Size of the points of individuals. Default is 0.5.
- alpha
Transparency of the points or labels of individuals. Default is 0.6.
- repel
Logical. When type="inames"", should labels of individuals be repeled ? Default is FALSE.
- text.size
Size of the labels of individuals. Default is 2.
- density
If NULL (default), no density layer is added. If "contour", density is plotted with contours. If "hex", density is plotted with hexagon bins.
- col.contour
character string. The color of the contours. Only used if density="contour".
- hex.bins
integer. The number of bins in both vertical and horizontal directions. Only used if density="hex".
- hex.pal
character string. The name of a viridis palette for hexagon bins. Only used if density="hex".
- aspect
Logical. TRUE (default) ensures that one unit on the x-axis is the same length as one unit on the y-axis.