Learn R Programming

GDAtools (version 1.0)

plot.multiMCA: Plots Multiple Factor Analysis

Description

Plots Multiple Factor Analysis data, resulting from multiMCA function.

Usage

## S3 method for class 'multiMCA':
plot(x, type = "v", axes = c(1, 2), points = "all", 
groups = 1:x$call$ngroups, col = rainbow(x$call$ngroups), app = 0, ...)

Arguments

Details

A category is considered to be one of the most correlated to a given axis if its test-value is higher then 2.58 (which corresponds to a 0.05 threshold).

References

Escofier, B. and Pages, J. (1994) "Multiple Factor Analysis (AFMULT package)". Computational Statistics and Data Analysis, 18, 121-140.

See Also

multiMCA, textvarsup, speMCA, csMCA, MFA

Examples

Run this code
## Performs a specific MCA on music variables of 'Taste' example data set,
## another one on movie variables of 'Taste' example data set, 
## and then a Multiple Factor Analysis and plots the results.
data(Taste)
mca1 <- speMCA(Taste[,1:5],excl=c(3,6,9,12,15))
mca2 <- speMCA(Taste[,6:11],excl=c(3,6,9,12,15,18))
mfa <- multiMCA(list(mca1,mca2))
plot.multiMCA(mfa,col=c('darkred','darkblue'))
plot.multiMCA(mfa,groups=2,app=1)

Run the code above in your browser using DataLab