Learn R Programming

GDAtools (version 1.0)

plot.speMCA: Plots 'specific' MCA results

Description

Plots a 'specific' Multiple Correspondence Analysis (resulting from speMCA function), i.e. the clouds of individuals or categories.

Usage

## S3 method for class 'speMCA':
plot(x, type = "v", axes = 1:2, points = "all", col = "dodgerblue4", app = 0, \dots)

Arguments

Details

A category is considered to be one of the most contributing to a given axis if its contribution is higher than the average contribution, i.e. 100 divided by the total number of categories.

References

Le Roux B. and Rouanet H., Multiple Correspondence Analysis, SAGE, Series: Quantitative Applications in the Social Sciences, Volume 163, CA:Thousand Oaks (2010).

Le Roux B. and Rouanet H., Geometric Data Analysis: From Correspondence Analysis to Stuctured Data Analysis, Kluwer Academic Publishers, Dordrecht (June 2004).

See Also

speMCA, textvarsup, conc.ellipse

Examples

Run this code
## Performs a specific MCA on 'Music' example data set
## ignoring every 'NA' (i.e. 'not available') categories,
## and then draws the cloud of categories.
data(Music)
getindexcat(Music[,1:5])
mca <- speMCA(Music[,1:5],excl=c(3,6,9,12,15))
plot(mca)
plot(mca,axes=c(2,3),points='best',col='darkred',app=1)

Run the code above in your browser using DataLab