Learn R Programming

GDAtools (version 1.0)

plot.stMCA: Plots 'standardized' MCA results

Description

Plots a 'standardized' Multiple Correspondence Analysis (resulting from stMCA function), i.e. the clouds of individuals or categories.

Usage

## S3 method for class 'stMCA':
plot(x, type = "v", axes = 1:2, points = "all", groups=NULL, 
                            col = "dodgerblue4", app = 0, \dots)

Arguments

Details

A category is considered to be one of the most correlated to a given axis if its test-value is higher then 2.58 (which corresponds to a 0.05 threshold).

References

Robette, Bry and Roueff, 2014, "Un dialogue de sourds dans le theatre statistique? Analyse geometrique des donnees et effets de structure", forthcoming

See Also

stMCA, textvarsup, conc.ellipse

Examples

Run this code
## Performs a standardized MCA on 'Music' example data set
## ignoring every 'NA' (i.e. 'not available') categories 
## and controlling for age,
## and then draws the cloud of categories.
data(Music)
mca <- speMCA(Music[,1:5],excl=c(3,6,9,12,15))
stmca <- stMCA(mca,control=list(Music$Age))
plot(stmca)
plot(stmca,axes=c(2,3),points='best',col='darkred',app=1)

Run the code above in your browser using DataLab