Learn R Programming

GDAtools (version 2.3.1)

reshape_between: Reshapes objects created with bcMCA()

Description

reshapes objects created with `bcMCA()` so that they can be used with other functions from the package.

Usage

reshape_between(bcmca)

Value

Returns an object of class bcMCA

Arguments

bcmca

object created with bcMCA function

Author

Nicolas Robette

References

Abdi H., 2007, "Discriminant Correspondence Analysis", In: Neil Salkind (Ed.), Encyclopedia of Measurement and Statistics, Thousand Oaks (CA): Sage.

Bry X., 1996, Analyses factorielles multiples, Economica.

Lebart L., Morineau A. et Warwick K., 1984, Multivariate Descriptive Statistical Analysis, John Wiley and sons, New-York.)

See Also

bcMCA

Examples

Run this code
data(tea, package = "FactoMineR")
res <- bcMCA(tea[,1:18], tea$SPC)
res_ok <- reshape_between(res)
ggcloud_variables(res_ok)

Run the code above in your browser using DataLab