Learn R Programming

GDAtools (version 2.3.1)

angles.csa: Cosine similarities and angles between CSA and MCA

Description

Computes the cosines similarities and angles between the components of a CSA and those of a MCA.

Usage

angles.csa(rescsa, resmca, naxes = 3)

Value

A list of matrices:

cosines

Cosine similarities between CSA and MCA dimensions

angles.with.dims

Angles between CSA and MCA dimensions

angles.with.planes

Angles between CSA dimensions and MCA planes

best.planes

Angles between each CSA dimension and its closest MCA plane

Arguments

rescsa

object of class csMCA

resmca

object of class MCA or speMCA

naxes

integer. Number of axes to retain. Default is 3.

Author

Lucas Page Pereira, Nicolas Robette

References

Le Roux B. and Rouanet H., Multiple Correspondence Analysis, SAGE, Series: Quantitative Applications in the Social Sciences, Volume 163, CA:Thousand Oaks (2010).

Le Roux B. and Rouanet H., Geometric Data Analysis: From Correspondence Analysis to Stuctured Data Analysis, Kluwer Academic Publishers, Dordrecht (June 2004).

See Also

MCA, speMCA, csMCA

Examples

Run this code
## Performs a specific MCA and a CSA on the Music example data set
## and computes cosine similarities and angles
data(Music)
junk <- c("FrenchPop.NA", "Rap.NA", "Rock.NA", "Jazz.NA", "Classical.NA")
resmca <- speMCA(Music[,1:5], excl = junk)
female <- Music$Gender=="Women"
rescsa <- csMCA(Music[,1:5], subcloud = female, excl = junk)
angles.csa(rescsa, resmca)

Run the code above in your browser using DataLab