contrib: Computes contributions for a correspondence analysis
Description
From MCA results, computes contributions of categories and variables to the axes and the overall cloud.
Usage
contrib(resmca)
Arguments
Value
A list of data frames:
ctrData frame with the contributions of categories to axes
var.ctrData frame with the contributions of variables to axes
ctr.cloudData frame with the contributions of categories to the overall cloud
vctr.cloudData frame with the contributions of variables to the overall cloud
Details
The contribution of a point to an axis depends both on the distance from the point to the origin point along the axis
and on the weight of the point. The contributions of points to axes are the main aid to interpretation
(see Le Roux and Rouanet, 2004 and 2010).
References
Le Roux B. and Rouanet H., Multiple Correspondence Analysis, SAGE, Series: Quantitative Applications in the Social Sciences, Volume 163, CA:Thousand Oaks (2010).
Le Roux B. and Rouanet H., Geometric Data Analysis: From Correspondence Analysis to Stuctured Data Analysis, Kluwer Academic Publishers, Dordrecht (June 2004).
## Performs a specific MCA on the 'Music' example data set## and compute contributionsdata(Music)
mca <- speMCA(Music[,1:5],excl=c(3,6,9,12,15))
contrib(mca)