Learn R Programming

GDAtools (version 1.0)

dimcontrib: Describes the contributions to axes for MCA and variants of MCA

Description

Identifies the categories and individuals that contribute the most characteristic according to each dimension obtained by a Factor Analysis. It allows to analyze variants of MCA, such as 'specific' MCA or 'class specific' MCA.

Usage

dimcontrib(resmca, dim = c(1,2), best = TRUE)

Arguments

Value

  • Returns a list:
  • vara list of categories' contributions to axes
  • inda list of individuals' contributions to axes

Details

Contributions are sorted and assigned a positive or negative sign according to the corresponding categories or individuals' coordinates, so as to facilitate interpretation.

References

Le Roux B. and Rouanet H., Multiple Correspondence Analysis, SAGE, Series: Quantitative Applications in the Social Sciences, Volume 163, CA:Thousand Oaks (2010).

Le Roux B. and Rouanet H., Geometric Data Analysis: From Correspondence Analysis to Stuctured Data Analysis, Kluwer Academic Publishers, Dordrecht (June 2004).

See Also

dimdesc, dimdesc.MCA, dimeta2, condes, speMCA, csMCA

Examples

Run this code
## Performs a specific MCA on 'Music' example data set
## ignoring every 'NA' (i.e. 'not available') categories,
## and then describe the contributions to axes.
data(Music)
getindexcat(Music[,1:5])
mca <- speMCA(Music[,1:5],excl=c(3,6,9,12,15))
dimcontrib(mca)

Run the code above in your browser using DataLab