Learn R Programming

GDAtools (version 1.0)

modif.rate: Computes the modified rates of variance of a correspondence analysis

Description

Computes the modified rates of variance of a correspondence analysis.

Usage

modif.rate(resmca)

Arguments

Value

  • Returns a data frame with 2 variables:
  • mrateNumeric vector of modified rates
  • cum.mrateNumeric vector of cumulative modified rates

Details

As MCA clouds often have a high dimensionality, the variance rates of the first principle axes may be quite low, which makes them hard to interpret. Benzecri (1992, p.412) proposed to use modified rates to better appreciate the relative importance of the principal axes.

References

Benzecri J.P., Correspondence analysis handbook, New-York: Dekker (1992).

Le Roux B. and Rouanet H., Multiple Correspondence Analysis, SAGE, Series: Quantitative Applications in the Social Sciences, Volume 163, CA:Thousand Oaks (2010).

Le Roux B. and Rouanet H., Geometric Data Analysis: From Correspondence Analysis to Stuctured Data Analysis, Kluwer Academic Publishers, Dordrecht (June 2004).

See Also

MCA, speMCA, csMCA

Examples

Run this code
## Computes the modified rates of variance
## of the MCA of 'Music' example data set
data(Music)
mca <- speMCA(Music[,1:5])
modif.rate(mca)

Run the code above in your browser using DataLab