powered by
reshapes objects created with `bcMCA()` so that they can be used with other functions from the package.
reshape_between(bcmca)
Returns an object of class bcMCA
bcMCA
object created with bcMCA function
Nicolas Robette
Abdi H., 2007, "Discriminant Correspondence Analysis", In: Neil Salkind (Ed.), Encyclopedia of Measurement and Statistics, Thousand Oaks (CA): Sage.
Bry X., 1996, Analyses factorielles multiples, Economica.
Lebart L., Morineau A. et Warwick K., 1984, Multivariate Descriptive Statistical Analysis, John Wiley and sons, New-York.)
data(tea, package = "FactoMineR") res <- bcMCA(tea[,1:18], tea$SPC) res_ok <- reshape_between(res) ggcloud_variables(res_ok)
Run the code above in your browser using DataLab