Learn R Programming

GDAtools (version 2.3.1)

scaled.dev: Scaled deviations for a categorical supplementary variable

Description

From MCA results, computes scaled deviations between categories for a categorical supplementary variable.

Usage

scaled.dev(resmca, var)

Value

Returns a list with one matrix for each dimension of the MCA. Each matrix is filled with scaled deviations between the categories of the supplementary variable, for a given dimension.

Arguments

resmca

object created with MCA, speMCA, csMCA, wcMCA, bcMCA, stMCA or multiMCA function

var

the categorical supplementary variable. It does not need to have been used at the MCA step.

Author

Nicolas Robette

References

Le Roux B. and Rouanet H., Multiple Correspondence Analysis, SAGE, Series: Quantitative Applications in the Social Sciences, Volume 163, CA:Thousand Oaks (2010).

Le Roux B. and Rouanet H., Geometric Data Analysis: From Correspondence Analysis to Stuctured Data Analysis, Kluwer Academic Publishers, Dordrecht (June 2004).

See Also

supvar, supvars, ggadd_supvar, ggadd_supvars, textvarsup, supind

Examples

Run this code
# specific MCA of Music example data set
data(Music)
junk <- c("FrenchPop.NA", "Rap.NA", "Rock.NA", "Jazz.NA", "Classical.NA")
mca <- speMCA(Music[,1:5], excl = junk)
# computes scaled deviations for Age supplementary variable
scaled.dev(mca,Music$Age)

Run the code above in your browser using DataLab