Learn R Programming

GDAtools (version 1.0)

varsup: Computes statistics for a categorical supplementary variable

Description

From MCA results, computes statistics (weights, coordinates, contributions, test-values, variances) for a categorical supplementary variable.

Usage

varsup(resmca, var)

Arguments

Value

  • Returns a list:
  • weightnumeric vector of categories weights
  • coorddata frame of categories coordinates
  • cos2data frame of categories square cosine
  • vardata frame of categories within variances, variance between and within categories and variable square correlation ratio (eta2)
  • v.testdata frame of categories test-values

References

Le Roux B. and Rouanet H., Multiple Correspondence Analysis, SAGE, Series: Quantitative Applications in the Social Sciences, Volume 163, CA:Thousand Oaks (2010).

Le Roux B. and Rouanet H., Geometric Data Analysis: From Correspondence Analysis to Stuctured Data Analysis, Kluwer Academic Publishers, Dordrecht (June 2004).

See Also

speMCA, csMCA, multiMCA, textvarsup

Examples

Run this code
## Performs a specific MCA on 'Music' example data set
## ignoring every 'NA' (i.e. 'not available') categories,
## and then computes statistics for age supplementary variable.
data(Music)
getindexcat(Music)
mca <- speMCA(Music[,1:5],excl=c(3,6,9,12,15))
varsup(mca,Music$Age)

Run the code above in your browser using DataLab